# Multi Dates Picker

Multi Dates Picker (mdp) is a Drupal module that provides a custom field type allowing editors to configure and select multiple dates during which the associated content should be visible and published. This automates the publish and unpublish process for content, making it ideal for event-based or time-sensitive content scheduling.

The module also includes an exposed Views filter that enables filtering content based on the selected dates, allowing developers to create date-aware content listings easily.

For a complete module description, visit the [Multi Dates Picker project page](https://www.drupal.org/project/mdp).

## Table of Contents

- [Multi Dates Picker](#multi-dates-picker)
  - [Table of Contents](#table-of-contents)
  - [Features](#features)
  - [Requirements](#requirements)
  - [Installation](#installation)
    - [Using Composer](#using-composer)
    - [Enabling the Module](#enabling-the-module)
    - [Library Installation](#library-installation)
  - [Configuration](#configuration)
  - [Usage](#usage)
  - [Help and Support](#help-and-support)
  - [Maintainers](#maintainers)
  - [License](#license)

## Features

- Provides a custom field type for selecting multiple dates.
- Automates content visibility based on the selected dates.
- Offers a configurable separator for storing dates (comma, semicolon, space, or hyphen).
- Includes a Views filter for displaying content based on selected dates.
- Fully compatible with Drupal core—no contrib dependencies required.

## Requirements

- **Drupal**: 10.3 or higher
- [Multiple Dates Picker for jQuery UI](https://github.com/dubrox/Multiple-Dates-Picker-for-jQuery-UI) library.

## Installation

### Using Composer

To add the module to your project, run the following command:

```bash
composer require drupal/mdp
```

### Enabling the Module

Enable the module via Drush:

```bash
drush en mdp -y
```

Or enable it from the Drupal admin UI under **Extend** by selecting **Multi Dates Picker**.

### Library Installation

This module requires the Multiple Dates Picker for jQuery UI JavaScript library.

Place the library manually in the `/libraries/jquery-ui-multi-date-picker` directory
**OR** install it using Composer  to isolate the library declaration inside the module:

1. Make sure [`wikimedia/composer-merge-plugin`](https://github.com/wikimedia/composer-merge-plugin) is required in your root `composer.json`:

   ```bash
   composer require wikimedia/composer-merge-plugin
   ```

2. Add the following snippet to your root `composer.json`:

   ```json
   "extra": {
     "merge-plugin": {
       "include": [
         "web/modules/contrib/mdp/composer.json"
       ]
     }
   }
   ```

3. Then, require the library like so:

   ```bash
   composer require dubrox/jquery-ui-multi-date-picker
   ```

   This will install the library under `libraries/jquery-ui-multi-date-picker`.

## Configuration

1. Navigate to **Structure > Content types** and choose the content type where you want to use the MDP field.
2. Under **Manage fields**, add a new field of type **Multi Dates Picker**.
3. Configure the field settings (e.g., date format, selection constraints) according to your use case.

## Usage

After configuration, editors can use the MDP field to select multiple dates when creating or editing content.

You can use the selected dates in custom logic for content visibility, scheduling, or other date-based workflows. Additional contributed or custom modules can also take advantage of this field to enhance scheduling features.

Also you can use the MDP field like a filter in the content views that has the MDP field

## Help and Support

For a complete description and the latest updates, visit the [project page on Drupal.org](https://www.drupal.org/project/mdp).

To report bugs, suggest features, or follow development progress, please use the
[module issue queue](https://www.drupal.org/project/issues/mdp).

## Maintainers

This module is actively maintained. Contributions, bug reports, and feature suggestions are welcome via the issue queue.

## License

This module is distributed under the [GNU General Public License, version 2 or later (GPL-2.0+)](https://www.gnu.org/licenses/old-licenses/gpl-2.0.html).
