<?php

namespace Drupal\mdp\Plugin\Field\FieldFormatter;

use Drupal\Core\Field\FieldDefinitionInterface;
use Drupal\Core\Field\Attribute\FieldFormatter;
use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Field\FormatterBase;
use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\mdp\Services\MDPService;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Plugin implementation of the 'mdp' formatter.
 */
#[FieldFormatter(
  id: 'field_mdp_formatter',
  label: new TranslatableMarkup('MDP - Formatter'),
  field_types: [
    'field_mdp',
  ]
)]
class MDPCustomFormatter extends FormatterBase {

  /**
   * The MDPService service.
   *
   * @var \Drupal\mdp\Services\MDPService
   */
  protected MDPService $mdpService;

  /**
   * Constructs an ImageFormatter object.
   *
   * @param string $plugin_id
   *   The plugin_id for the formatter.
   * @param mixed $plugin_definition
   *   The plugin implementation definition.
   * @param \Drupal\Core\Field\FieldDefinitionInterface $field_definition
   *   The definition of the field to which the formatter is associated.
   * @param array $settings
   *   The formatter settings.
   * @param string $label
   *   The formatter label display setting.
   * @param string $view_mode
   *   The view mode.
   * @param array $third_party_settings
   *   Any third party settings.
   * @param \Drupal\mdp\Services\MDPService $mdpService
   *   The MDP service for date range validation.
   */
  public function __construct($plugin_id, $plugin_definition, FieldDefinitionInterface $field_definition, array $settings, $label, $view_mode, array $third_party_settings, MDPService $mdpService) {
    parent::__construct($plugin_id, $plugin_definition, $field_definition, $settings, $label, $view_mode, $third_party_settings);
    $this->mdpService = $mdpService;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $plugin_id,
      $plugin_definition,
      $configuration['field_definition'],
      $configuration['settings'],
      $configuration['label'],
      $configuration['view_mode'],
      $configuration['third_party_settings'],
      $container->get('mdp')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function viewElements(FieldItemListInterface $items, $langcode) {
    $elements = [];
    $separator = $this->fieldDefinition->getSetting('separator');
    foreach ($items as $delta => $item) {
      $dates[] = $this->mdpService->convertTimestampToDate($item->value, $separator, TRUE);
    }

    $elements[$delta] = [
      '#markup' => implode($separator, $dates ?? []),
    ];

    return $elements;
  }

}
