<?php

namespace Drupal\mdp\Services;

use Drupal\mdp\Plugin\Field\FieldType\MDPItem;

/**
 * Class MDPService.
 *
 * Providing functionality to determine if current date falls within a date
 * range.
 */
class MDPService {

  /**
   * Evaluates if the current date falls within the date range.
   *
   * @param string $dates
   *   Te date range string.
   * @param string $separator
   *   The separator for dates in the date range string.
   *
   * @return bool
   *   Returns TRUE if the current date is contained in the date range,
   *   otherwise it returns FALSE.
   */
  public function dateTimeInRange(string $dates, string $separator = ', '): bool {
    $currentDate = date('m/d/Y');
    $currentTime = time();
    $inRange = FALSE;
    $dates = $this->convertTimestampToDate($dates, $separator);
    $arrayDates = explode($separator, $dates);

    if (count($arrayDates) == 2) {
      $startTimestamp = strtotime($arrayDates[0] . " 00:00");
      $endTimestamp = strtotime($arrayDates[1] . " 23:59");
      if ($currentTime >= $startTimestamp && $currentTime <= $endTimestamp) {
        $inRange = TRUE;
      }
    }
    else {
      $pos = strpos($dates, $currentDate);
      if ($pos !== FALSE) {
        $startTimestamp = strtotime($currentDate . " 00:00");
        $endTimestamp = strtotime($currentDate . " 23:59");
        if ($currentTime >= $startTimestamp && $currentTime <= $endTimestamp) {
          $inRange = TRUE;
        }
      }
    }
    return $inRange;
  }

  /**
   * Converts timestamps of a date range string to 'm/d/Y' formatted dates.
   *
   * @param string $value
   *   Te date range string.
   * @param string $separator
   *   The separator for dates in the date range string.
   *
   * @return string
   *   Date range string with dates in the format 'm/d/Y'..
   */
  public function convertTimestampToDate($value, $separator = ', ', $isStrtotime = FALSE) {
    $value = $isStrtotime ? $value : strtotime($value);

    if ($value) {
      $formattedDates = [];
      foreach (explode($separator, $value) as $timestamp) {
        $formattedDates[] = date('m/d/Y', $timestamp);
      }
      $value = implode($separator, $formattedDates);
    }

    return $value;
  }

}
